==> everrest-core-1.0.1-sources.jar: org/everrest/core/impl/InternalException.java <==
/*
 * Copyright (C) 2009 eXo Platform SAS.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.everrest.core.impl;

/**
 * Should not be used by custom services. They have to use
 * {@link javax.ws.rs.WebApplicationException} instead. This Exception is used
 * as wrapper for exception that may occur during request processing.
 * 
 * @author <a href="mailto:andrew00x@gmail.com">Andrey Parfonov</a>
 * @version $Id: InternalException.java 71 2010-10-25 15:19:37Z andrew00x $
 */
public class InternalException extends RuntimeException
{

   /**
    * Serial Version UID.
    */
   private static final long serialVersionUID = -712006975338590407L;

   /**
    * @param s message
    * @param throwable cause
    */
   public InternalException(String s, Throwable throwable)
   {
      super(s, throwable);
   }

   /**
    * @param throwable cause
    */
   public InternalException(Throwable throwable)
   {
      super(throwable);
   }
}

==> everrest-core-1.0.3-sources.jar: org/everrest/core/impl/InternalException.java <==
/*
 * Copyright (C) 2009 eXo Platform SAS.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.everrest.core.impl;

/**
 * Should not be used by custom services. They have to use
 * {@link javax.ws.rs.WebApplicationException} instead. This Exception is used
 * as wrapper for exception that may occur during request processing.
 * 
 * @author <a href="mailto:andrew00x@gmail.com">Andrey Parfonov</a>
 * @version $Id: InternalException.java 406 2012-02-15 15:30:52Z andrew00x $
 */
@SuppressWarnings("serial")
public final class InternalException extends RuntimeException
{
   /**
    * @param s message
    * @param throwable cause
    */
   public InternalException(String s, Throwable throwable)
   {
      super(s, throwable);
   }

   /**
    * @param throwable cause
    */
   public InternalException(Throwable throwable)
   {
      super(throwable);
   }
}
